<?php

if (!defined("WHMCS")) {
    die("This file cannot be accessed directly.");
}

function voidpanel_MetaData() {
    return [
        'DisplayName' => 'VoidPanel',
        'APIVersion' => '1.0',
        'RequiresServer' => true
    ];
}

function voidpanel_ConfigOptions() {
    return [
        'package' => [
            'FriendlyName' => 'Package Name',
            'Type' => 'text',
            'Size' => '25',
            'Default' => 'default_package',
            'Description' => 'Enter the package name in VoidPanel'
        ],
        'Secure Connection' => [
            'FriendlyName' => 'Secure Connection',
            'Type' => 'yesno',
            'Description' => 'Tick this box for a secure (HTTPS) connection.'
        ]
    ];
}

function voidpanel_getBaseUrl($params) {
    $secure = (!empty($params['configoption2']) && $params['configoption2'] === 'on');
    $protocol = $secure ? 'https' : 'http';
    $port = $secure ? 8082 : 8080;
    $host = rtrim($params['serverhostname'], '/');
    return "{$protocol}://{$host}:{$port}";
}

function voidpanel_Authenticate($params) {
    $baseUrl = voidpanel_getBaseUrl($params);
    $apiUrl = "{$baseUrl}/api/auth/";
    $username = $params['serverusername'];
    $password = $params['serverpassword'];

    $response = voidpanel_sendRequest($apiUrl, [
        'username' => $username,
        'password' => $password
    ]);

    logModuleCall('voidpanel', 'Authenticate', ['apiUrl' => $apiUrl, 'username' => $username], $response);

    return (!empty($response['status']) && $response['status'] === 'success') ? $response['session_token'] : false;
}

function voidpanel_CreateAccount($params) {
    $sessionToken = voidpanel_Authenticate($params);
    if (!$sessionToken) return ['success' => false, 'message' => 'Authentication failed.'];

    $baseUrl = voidpanel_getBaseUrl($params);
    $apiUrl = "{$baseUrl}/api/create-account/";
    $data = [
        'session_token' => $sessionToken,
        'domain' => $params['domain'],
        'username' => $params['username'],
        'password' => $params['password'],
        'package' => $params['configoption1'],
        'client_id' => $params['clientsdetails']['userid']
    ];

    $response = voidpanel_sendRequest($apiUrl, $data);
    logModuleCall('voidpanel', 'CreateAccount', $data, $response);

    return (!empty($response['status']) && $response['status'] === 'success') ? 'success' : 'Error: ' . ($response['message'] ?? 'Unknown error');
}


function voidpanel_AutoLogin($params) {
 
    $debugFile = __DIR__ . '/a.txt';
    file_put_contents($debugFile, "voidpanel_AutoLogin called at " . date('Y-m-d H:i:s') . "\n", FILE_APPEND);

    // Rest of your code...
    $sessionToken = voidpanel_Authenticate($params);
    file_put_contents($debugFile, "Session Token: " . var_export($sessionToken, true) . "\n", FILE_APPEND);

    if (!$sessionToken) {
        file_put_contents($debugFile, "Authentication failed\n", FILE_APPEND);
        return ['success' => false, 'message' => 'Authentication failed.'];
    }

    $baseUrl = voidpanel_getBaseUrl($params);
    file_put_contents($debugFile, "Base URL: " . $baseUrl . "\n", FILE_APPEND);

    $loginUrl = "{$baseUrl}/dashboard?session_token=" . urlencode($sessionToken);
    file_put_contents($debugFile, "Login URL: " . $loginUrl . "\n", FILE_APPEND);

    $returnData = ['success' => true, 'redirect' => $loginUrl];
    file_put_contents($debugFile, "Return Data: " . print_r($returnData, true) . "\n", FILE_APPEND);

    return $returnData;
}


function voidpanel_Action($params, $endpoint, $action) {
    $sessionToken = voidpanel_Authenticate($params);
    if (!$sessionToken) return ['success' => false, 'message' => 'Authentication failed.'];

    $baseUrl = voidpanel_getBaseUrl($params);
    $apiUrl = "{$baseUrl}{$endpoint}";
    $data = ['session_token' => $sessionToken, 'username' => $params['username']];

    $response = voidpanel_sendRequest($apiUrl, $data);
    logModuleCall('voidpanel', $action, $data, $response);

    return (!empty($response['status']) && $response['status'] === 'success')
        ? ['success' => true, 'message' => ucfirst($action) . ' successful.']
        : ['success' => false, 'message' => 'Error: ' . ($response['message'] ?? 'Unknown error')];
}

function voidpanel_AdminCustomButtonArray() {
    return ["Verify Connection" => "testConnection"];
}

function voidpanel_testConnection($params) {
    $sessionToken = voidpanel_Authenticate($params);
    logModuleCall('voidpanel', 'Test Connection', $params, $sessionToken);

    return $sessionToken
        ? ['success' => true, 'message' => "✅ Successfully connected to VoidPanel!"]
        : ['success' => false, 'message' => "❌ Connection failed. Check credentials and API URL."];
}

function voidpanel_sendRequest($url, $data) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
    curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/json']);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);

    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    $error = curl_error($ch);
    curl_close($ch);

    if ($error) {
        return ['status' => 'error', 'message' => 'cURL Error: ' . $error];
    }

    $decoded = json_decode($response, true);
    return $decoded ?: ['status' => 'error', 'message' => 'Invalid JSON. HTTP Code: ' . $httpCode];
}

?>
